@@ -15,28 +15,76 @@ our @EXPORT = qw(
 our @EXPORT_OK = qw(
 totalmem
 freemem
+totalswap
+freeswap
+availkeys
+get
 );
-our $VERSION = 0.04;
+our $VERSION = 0.90;
 bootstrap Sys::MemInfo $VERSION;
 
+sub get {
+  my $field = shift;
+  no strict;
+  return &{$field};
+}
+
 =pod
 
 Sys::MemInfo - Memory informations
 
 =head1 SYNOPSIS
 
-  use Sys::MemInfo qw(totalmem freemem);
+  use Sys::MemInfo qw(totalmem freemem totalswap);
 
   print "total memory: ".(&totalmem / 1024)."\n";
   print "free memory:  ".(&freemem / 1024)."\n";
 
+  print "total swap: ".(&totalswap / 1024)."\n";
+  print "free swap:  ".(Sys::MemInfo::get("freeswap") / 1024)."\n";
+
 =head1 DESCRIPTION
 
 Sys::MemInfo return the total amount of free and used physical memory in bytes in totalmem and freemem variables.
 
-This module has been tested on Linux, OpenUnix, AIX5, OpenBSD, HPUX11, Tru64 5.1 and Windows XP.
+Total amount of free and user swap memory are alse returned in totalswap and freeswap variables.
 
-It should work on Solaris, Windows Server 2003 and others *bsd systems like FreeBSD and NetBSD.
+This module has been tested on Linux 2.6.10, UnixWare 7.1.2, AIX5, OpenBSD 3.8, 
+NetBSD 2.0.2, FreBSD 5.4, HPUX11, Solaris 9, Tru64 5.1, Irix 6.5 and Windows XP.
+
+It should work on FreeBSD 4 and Windows 9X/ME/NT/200X/Vista.
+
+=head1 METHODS
+
+=over 4
+
+=item availkeys
+
+Return list of all accessor keys (freemem, totalmem, etc.)  This is useful
+for dumping out all known information from the object by calling get() on
+all of the returned keys.
+
+=item freemem
+
+Returns free physical memory in bytes.
+
+=item freeswap
+
+Returns free swap space in bytes.
+
+=item get
+
+Returns the value of the passed key.
+
+=item totalmem
+
+Returns total physical memory size in bytes.
+
+=item totalswap
+
+Returns total swap space in bytes.
+
+=back
 
 =head1 AUTHOR
 
@@ -65,7 +113,9 @@ USA
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005 - Sylvain Cresto
+Copyright (C) 2005, 2006 - Sylvain Cresto
+
+Thanks to Laurent Dufour and Wilson Snyder.
 
 =cut
 
